#[non_exhaustive]pub enum JournalMode {
Delete,
Wal,
}Expand description
The SQLite journal mode.
You can change the journal mode of a connection with Connection::set_journal_mode.
See the SQLite documentation on journal modes for details.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Delete
The DELETE journal mode.
This is the default SQLite journal mode.
Wal
The WAL journal mode.
Write-ahead logging can improve performance and concurrency, but comes with caveats. See the SQLite documentation on write-ahead logging for details.
Bench testing has found that enabling write-ahead logging for LiteboxFS improves read and write performance for small files, but degrades performance for large files. Your results may vary, so if performance is critical, consider benchmarking your workload to see whether enabling write-ahead logging makes sense.